@@ -19,7 +19,7 @@
 //! # fn slow_code(){}
 //! ```
 
-// BEGIN - Embark standard lints v0.4
+// BEGIN - Embark standard lints v5 for Rust 1.55+
 // do not change or add/remove here, but one can add exceptions after this section
 // for more info see: <https://github.com/EmbarkStudios/rust-ecosystem/issues/59>
 #![deny(unsafe_code)]
@@ -30,6 +30,8 @@
     clippy::checked_conversions,
     clippy::dbg_macro,
     clippy::debug_assert_with_mut_call,
+    clippy::disallowed_method,
+    clippy::disallowed_type,
     clippy::doc_markdown,
     clippy::empty_enum,
     clippy::enum_glob_use,
@@ -39,13 +41,17 @@
     clippy::explicit_into_iter_loop,
     clippy::fallible_impl_from,
     clippy::filter_map_next,
+    clippy::flat_map_option,
     clippy::float_cmp_const,
     clippy::fn_params_excessive_bools,
+    clippy::from_iter_instead_of_collect,
     clippy::if_let_mutex,
     clippy::implicit_clone,
     clippy::imprecise_flops,
     clippy::inefficient_to_string,
     clippy::invalid_upcast_comparisons,
+    clippy::large_digit_groups,
+    clippy::large_stack_arrays,
     clippy::large_types_passed_by_value,
     clippy::let_unit_value,
     clippy::linkedlist,
@@ -57,20 +63,25 @@
     clippy::map_unwrap_or,
     clippy::match_on_vec_items,
     clippy::match_same_arms,
+    clippy::match_wild_err_arm,
     clippy::match_wildcard_for_single_variants,
     clippy::mem_forget,
     clippy::mismatched_target_os,
+    clippy::missing_enforced_import_renames,
     clippy::mut_mut,
     clippy::mutex_integer,
     clippy::needless_borrow,
     clippy::needless_continue,
+    clippy::needless_for_each,
     clippy::option_option,
     clippy::path_buf_push_overwrite,
     clippy::ptr_as_ptr,
+    clippy::rc_mutex,
     clippy::ref_option_ref,
     clippy::rest_pat_in_fully_bound_structs,
     clippy::same_functions_in_if_condition,
     clippy::semicolon_if_nothing_returned,
+    clippy::single_match_else,
     clippy::string_add_assign,
     clippy::string_add,
     clippy::string_lit_as_bytes,
@@ -87,7 +98,7 @@
     nonstandard_style,
     rust_2018_idioms
 )]
-// END - Embark standard lints v0.4
+// END - Embark standard lints v0.5 for Rust 1.55+
 // crate-specific exceptions:
 
 mod data;
@@ -108,15 +119,15 @@ use std::sync::{
 
 static MACROS_ON: AtomicBool = AtomicBool::new(false);
 
-/// Turn on/off the profiler macros (`profile_function`, `profile_scope` etc).
+/// Turn on/off the profiler macros ([`profile_function`], [`profile_scope`] etc).
 /// When off, these calls take only 1-2 ns to call (100x faster).
-/// This is `false` by default.
+/// This is [`false`] by default.
 pub fn set_scopes_on(on: bool) {
     MACROS_ON.store(on, Ordering::Relaxed);
 }
 
 /// Are the profiler scope macros turned on?
-/// This is `false` by default.
+/// This is [`false`] by default.
 pub fn are_scopes_on() -> bool {
     MACROS_ON.load(Ordering::Relaxed)
 }
@@ -230,7 +241,7 @@ pub struct StreamInfo {
 
     /// The smallest and largest nanosecond value in the stream.
     ///
-    /// The default value is `(NanoSecond::MAX, NanoSecond::MIN)` which indicates an empty stream.
+    /// The default value is ([`NanoSecond::MAX`], [`NanoSecond::MIN`]) which indicates an empty stream.
     pub range_ns: (NanoSecond, NanoSecond),
 }
 
@@ -248,7 +259,7 @@ impl Default for StreamInfo {
 impl StreamInfo {
     /// Parse a stream to count the depth, number of scopes in it etc.
     ///
-    /// Try to avoid calling this, and instead keep score while collecting a `StreamInfo`.
+    /// Try to avoid calling this, and instead keep score while collecting a [`StreamInfo`].
     pub fn parse(stream: Stream) -> Result<StreamInfo> {
         let top_scopes = Reader::from_start(&stream).read_top_scopes()?;
         if top_scopes.is_empty() {
@@ -318,7 +329,7 @@ pub struct StreamInfoRef<'a> {
 
     /// The smallest and largest nanosecond value in the stream.
     ///
-    /// The default value is `(NanoSecond::MAX, NanoSecond::MIN)` which indicates an empty stream.
+    /// The default value is ([`NanoSecond::MAX`], [`NanoSecond::MIN`]) which indicates an empty stream.
     pub range_ns: (NanoSecond, NanoSecond),
 }
 
@@ -357,10 +368,10 @@ impl Default for ThreadProfiler {
 impl ThreadProfiler {
     /// Explicit initialize with custom callbacks.
     ///
-    /// If not called, each thread will use the default nanosecond source (`[now_ns]`)
-    /// and report scopes to the global profiler ([`global_reporter`]).
+    /// If not called, each thread will use the default nanosecond source ([`now_ns()`])
+    /// and report scopes to the global profiler ([`global_reporter()`]).
     ///
-    /// For instance, when compiling for WASM the default timing function (`[now_ns]`) won't work,
+    /// For instance, when compiling for WASM the default timing function ([`now_ns()`]) won't work,
     /// so you'll want to call `puffin::ThreadProfiler::initialize(my_timing_function, puffin::global_reporter);`.
     pub fn initialize(now_ns: NsSource, reporter: ThreadReporter) {
         ThreadProfiler::call(|tp| {
@@ -421,7 +432,7 @@ impl ThreadProfiler {
 
 // ----------------------------------------------------------------------------
 
-/// Add these to [`GlobalProfiler`] with [`GlobalProfiler::add_sink`].
+/// Add these to [`GlobalProfiler`] with [`GlobalProfiler::add_sink()`].
 pub type FrameSink = Box<dyn Fn(Arc<FrameData>) + Send>;
 
 /// Identifies a specific [`FrameSink`] when added to [`GlobalProfiler`].
@@ -429,7 +440,7 @@ pub type FrameSink = Box<dyn Fn(Arc<FrameData>) + Send>;
 pub struct FrameSinkId(u64);
 
 /// Singleton. Collects profiling data from multiple threads
-/// and passes them on to different [`FrameSink`]:s.
+/// and passes them on to different [`FrameSink`]s.
 pub struct GlobalProfiler {
     current_frame_index: FrameIndex,
     current_frame: BTreeMap<ThreadInfo, StreamInfo>,
@@ -507,7 +518,7 @@ impl GlobalProfiler {
 
     /// Tells [`GlobalProfiler`] to call this function with each new finished frame.
     ///
-    /// The returned [`FrameSinkId`] can be used to remove the sink with [`Self::remove_sink`].
+    /// The returned [`FrameSinkId`] can be used to remove the sink with [`Self::remove_sink()`].
     pub fn add_sink(&mut self, sink: FrameSink) -> FrameSinkId {
         let id = self.next_sink_id;
         self.next_sink_id.0 += 1;
