@@ -2,7 +2,7 @@ use std::sync::{Arc, Mutex};
 
 use crate::{FrameData, FrameSinkId};
 
-/// A view of recent and slowest frames, used by GUI:s.
+/// A view of recent and slowest frames, used by GUIs.
 #[derive(Clone)]
 pub struct FrameView {
     /// newest first
@@ -80,7 +80,7 @@ impl FrameView {
         self.recent.iter()
     }
 
-    /// The slowest frames so far (or since last call to [`Self::clear_slowest`])
+    /// The slowest frames so far (or since last call to [`Self::clear_slowest()`])
     /// in chronological order.
     pub fn slowest_frames_chronological(&self) -> Vec<Arc<FrameData>> {
         let mut frames: Vec<_> = self.slowest.iter().map(|f| f.0.clone()).collect();
@@ -124,6 +124,7 @@ impl FrameView {
 
     /// Export profile data as a `.puffin` file.
     #[cfg(feature = "serialization")]
+    #[cfg(not(target_arch = "wasm32"))] // compression not supported on wasm
     pub fn save_to_path(&self, path: &std::path::Path) -> anyhow::Result<()> {
         let mut file = std::fs::File::create(path)?;
         self.save_to_writer(&mut file)
@@ -131,6 +132,7 @@ impl FrameView {
 
     /// Export profile data as a `.puffin` file.
     #[cfg(feature = "serialization")]
+    #[cfg(not(target_arch = "wasm32"))] // compression not supported on wasm
     pub fn save_to_writer(&self, write: &mut impl std::io::Write) -> anyhow::Result<()> {
         write.write_all(b"PUF0")?;
 
